@@ -220,13 +220,14 @@ address_family_str (GdmAddress *address)
 
 static void
 _gdm_address_debug (GdmAddress *address,
+                    const char *hostname,
                     const char *host,
                     const char *port)
 {
-        g_debug ("Address family:%d (%s) host:%s port:%s local:%d loopback:%d",
-
+        g_debug ("Address family:%d (%s) hostname:%s host:%s port:%s local:%d loopback:%d",
                  address->ss->ss_family,
                  address_family_str (address) ? address_family_str (address) : "(null)",
+                 hostname ? hostname : "(null)",
                  host ? host : "(null)",
                  port ? port : "(null)",
                  gdm_address_is_local (address),
@@ -236,14 +237,13 @@ _gdm_address_debug (GdmAddress *address,
 void
 gdm_address_debug (GdmAddress *address)
 {
-        char *hostname = NULL;
-        char *host = NULL;
-        char *port = NULL;
+        char *hostname;
+        char *host;
+        char *port;
 
+        gdm_address_get_hostname (address, &hostname);
         gdm_address_get_numeric_info (address, &host, &port);
 
-        _gdm_address_debug (address, host, port);
-
         g_free (hostname);
         g_free (host);
         g_free (port);
@@ -277,8 +277,7 @@ gdm_address_get_hostname (GdmAddress *address,
                 err_msg = gai_strerror (res);
                 g_warning ("Unable to lookup hostname: %s",
                         err_msg ? err_msg : "(null)");
-                _gdm_address_debug (address, NULL, NULL);
-
+                _gdm_address_debug (address, NULL, NULL, NULL);
         }
 
         /* try numeric? */
@@ -319,7 +318,7 @@ gdm_address_get_numeric_info (GdmAddress *address,
                 err_msg = gai_strerror (res);
                 g_warning ("Unable to lookup numeric info: %s",
                         err_msg ? err_msg : "(null)");
-                _gdm_address_debug (address, NULL, NULL);
+                _gdm_address_debug (address, NULL, NULL, NULL);
         } else {
                 ret = TRUE;
         }
@@ -405,6 +404,8 @@ add_local_siocgifconf (GList **list)
                                         address = gdm_address_new_from_sockaddr ((struct sockaddr *)&ifreq.ifr_addr,
                                                                                  sizeof (struct sockaddr));
 
+                                        gdm_address_debug (address);
+
                                         *list = g_list_append (*list, address);
                                 }
                         }
@@ -436,8 +437,7 @@ add_local_addrinfo (GList **list)
 
         memset (&hints, 0, sizeof (hints));
         hints.ai_family = AF_UNSPEC;
-        hints.ai_flags = AI_CANONNAME | AI_NUMERICHOST;
-
+        hints.ai_flags = AI_CANONNAME;
 
         g_debug ("GdmAddress: looking up hostname: %s", hostbuf);
         result = NULL;
