@@ -36,23 +36,17 @@
 #include <glib-object.h>
 
 #include "gdm-display.h"
-#include "gdm-launch-environment.h"
 #include "gdm-xdmcp-display.h"
 
 #include "gdm-common.h"
 #include "gdm-address.h"
 
-#include "gdm-settings.h"
-#include "gdm-settings-direct.h"
-#include "gdm-settings-keys.h"
-
 #define GDM_XDMCP_DISPLAY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GDM_TYPE_XDMCP_DISPLAY, GdmXdmcpDisplayPrivate))
 
 struct GdmXdmcpDisplayPrivate
 {
         GdmAddress             *remote_address;
         gint32                  session_number;
-        guint                   connection_attempts;
 };
 
 enum {
@@ -61,12 +55,11 @@ enum {
         PROP_SESSION_NUMBER,
 };
 
-#define MAX_CONNECT_ATTEMPTS  10
-
 static void     gdm_xdmcp_display_class_init    (GdmXdmcpDisplayClass *klass);
 static void     gdm_xdmcp_display_init          (GdmXdmcpDisplay      *xdmcp_display);
+static void     gdm_xdmcp_display_finalize      (GObject              *object);
 
-G_DEFINE_TYPE (GdmXdmcpDisplay, gdm_xdmcp_display, GDM_TYPE_DISPLAY)
+G_DEFINE_ABSTRACT_TYPE (GdmXdmcpDisplay, gdm_xdmcp_display, GDM_TYPE_DISPLAY)
 
 gint32
 gdm_xdmcp_display_get_session_number (GdmXdmcpDisplay *display)
@@ -84,6 +77,50 @@ gdm_xdmcp_display_get_remote_address (GdmXdmcpDisplay *display)
         return display->priv->remote_address;
 }
 
+static gboolean
+gdm_xdmcp_display_create_authority (GdmDisplay *display)
+{
+        g_return_val_if_fail (GDM_IS_DISPLAY (display), FALSE);
+
+        return GDM_DISPLAY_CLASS (gdm_xdmcp_display_parent_class)->create_authority (display);
+}
+
+static gboolean
+gdm_xdmcp_display_add_user_authorization (GdmDisplay *display,
+                                          const char *username,
+                                          char      **filename,
+                                          GError    **error)
+{
+        return GDM_DISPLAY_CLASS (gdm_xdmcp_display_parent_class)->add_user_authorization (display, username, filename, error);
+}
+
+static gboolean
+gdm_xdmcp_display_remove_user_authorization (GdmDisplay *display,
+                                             const char *username,
+                                             GError    **error)
+{
+        return GDM_DISPLAY_CLASS (gdm_xdmcp_display_parent_class)->remove_user_authorization (display, username, error);
+}
+
+static gboolean
+gdm_xdmcp_display_manage (GdmDisplay *display)
+{
+        g_return_val_if_fail (GDM_IS_DISPLAY (display), FALSE);
+
+        GDM_DISPLAY_CLASS (gdm_xdmcp_display_parent_class)->manage (display);
+
+        return TRUE;
+}
+
+static gboolean
+gdm_xdmcp_display_unmanage (GdmDisplay *display)
+{
+        g_return_val_if_fail (GDM_IS_DISPLAY (display), FALSE);
+
+        GDM_DISPLAY_CLASS (gdm_xdmcp_display_parent_class)->unmanage (display);
+        return TRUE;
+}
+
 static void
 _gdm_xdmcp_display_set_remote_address (GdmXdmcpDisplay *display,
                                        GdmAddress      *address)
@@ -144,74 +181,15 @@ gdm_xdmcp_display_get_property (GObject    *object,
         }
 }
 
-static gboolean
-gdm_xdmcp_display_prepare (GdmDisplay *display)
-{
-        GdmXdmcpDisplay *self = GDM_XDMCP_DISPLAY (display);
-        GdmLaunchEnvironment *launch_environment;
-        char          *display_name;
-        char          *seat_id;
-        char          *hostname;
-
-        launch_environment = NULL;
-        display_name = NULL;
-        seat_id = NULL;
-        hostname = NULL;
-
-        g_object_get (self,
-                      "x11-display-name", &display_name,
-                      "seat-id", &seat_id,
-                      "remote-hostname", &hostname,
-                      "launch-environment", &launch_environment,
-                      NULL);
-
-        if (launch_environment == NULL) {
-                launch_environment = gdm_create_greeter_launch_environment (display_name,
-                                                                            seat_id,
-                                                                            NULL,
-                                                                            hostname,
-                                                                            FALSE);
-                g_object_set (self, "launch-environment", launch_environment, NULL);
-                g_object_unref (launch_environment);
-        }
-
-        if (!gdm_display_create_authority (display)) {
-                g_warning ("Unable to set up access control for display %s",
-                           display_name);
-                return FALSE;
-        }
-
-        return GDM_DISPLAY_CLASS (gdm_xdmcp_display_parent_class)->prepare (display);
-}
-
-static gboolean
-idle_connect_to_display (GdmXdmcpDisplay *self)
-{
-        gboolean res;
-
-        self->priv->connection_attempts++;
-
-        res = gdm_display_connect (GDM_DISPLAY (self));
-        if (res) {
-                g_object_set (G_OBJECT (self), "status", GDM_DISPLAY_MANAGED, NULL);
-        } else {
-                if (self->priv->connection_attempts >= MAX_CONNECT_ATTEMPTS) {
-                        g_warning ("Unable to connect to display after %d tries - bailing out", self->priv->connection_attempts);
-                        gdm_display_unmanage (GDM_DISPLAY (self));
-                        return FALSE;
-                }
-                return TRUE;
-        }
-
-        return FALSE;
-}
-
 static void
-gdm_xdmcp_display_manage (GdmDisplay *display)
+gdm_xdmcp_display_get_timed_login_details (GdmDisplay *display,
+                                           gboolean   *enabledp,
+                                           char      **usernamep,
+                                           int        *delayp)
 {
-        GdmXdmcpDisplay *self = GDM_XDMCP_DISPLAY (display);
-
-        g_timeout_add (500, (GSourceFunc)idle_connect_to_display, self);
+        *enabledp = FALSE;
+        *usernamep = g_strdup ("");
+        *delayp = 0;
 }
 
 static void
@@ -222,9 +200,14 @@ gdm_xdmcp_display_class_init (GdmXdmcpDisplayClass *klass)
 
         object_class->get_property = gdm_xdmcp_display_get_property;
         object_class->set_property = gdm_xdmcp_display_set_property;
+        object_class->finalize = gdm_xdmcp_display_finalize;
 
-        display_class->prepare = gdm_xdmcp_display_prepare;
+        display_class->create_authority = gdm_xdmcp_display_create_authority;
+        display_class->add_user_authorization = gdm_xdmcp_display_add_user_authorization;
+        display_class->remove_user_authorization = gdm_xdmcp_display_remove_user_authorization;
         display_class->manage = gdm_xdmcp_display_manage;
+        display_class->unmanage = gdm_xdmcp_display_unmanage;
+        display_class->get_timed_login_details = gdm_xdmcp_display_get_timed_login_details;
 
         g_type_class_add_private (klass, sizeof (GdmXdmcpDisplayPrivate));
 
@@ -252,35 +235,20 @@ static void
 gdm_xdmcp_display_init (GdmXdmcpDisplay *xdmcp_display)
 {
 
-        gboolean allow_remote_autologin;
-
         xdmcp_display->priv = GDM_XDMCP_DISPLAY_GET_PRIVATE (xdmcp_display);
-
-        allow_remote_autologin = FALSE;
-        gdm_settings_direct_get_boolean (GDM_KEY_ALLOW_REMOTE_AUTOLOGIN, &allow_remote_autologin);
-
-        g_object_set (G_OBJECT (xdmcp_display), "allow-timed-login", allow_remote_autologin, NULL);
 }
 
-GdmDisplay *
-gdm_xdmcp_display_new (const char *hostname,
-                       int         number,
-                       GdmAddress *address,
-                       gint32      session_number)
+static void
+gdm_xdmcp_display_finalize (GObject *object)
 {
-        GObject *object;
-        char    *x11_display;
+        GdmXdmcpDisplay *xdmcp_display;
 
-        x11_display = g_strdup_printf ("%s:%d", hostname, number);
-        object = g_object_new (GDM_TYPE_XDMCP_DISPLAY,
-                               "remote-hostname", hostname,
-                               "x11-display-number", number,
-                               "x11-display-name", x11_display,
-                               "is-local", FALSE,
-                               "remote-address", address,
-                               "session-number", session_number,
-                               NULL);
-        g_free (x11_display);
+        g_return_if_fail (object != NULL);
+        g_return_if_fail (GDM_IS_XDMCP_DISPLAY (object));
 
-        return GDM_DISPLAY (object);
+        xdmcp_display = GDM_XDMCP_DISPLAY (object);
+
+        g_return_if_fail (xdmcp_display->priv != NULL);
+
+        G_OBJECT_CLASS (gdm_xdmcp_display_parent_class)->finalize (object);
 }
